@@ -1,4 +1,4 @@
-/* $Id: os-aix3.h,v 1.3 1991/06/17 14:01:13 chip Exp $
+/* $Id: os-aix3.h,v 1.4 1999/12/02 01:08:30 chip Exp $
  *
  * Deliver configuration for AIX 3.x.
  *
@@ -6,7 +6,10 @@
  * in "local.h" to put /usr/ucb before /usr/bin.
  *
  * $Log: os-aix3.h,v $
- * Revision 1.3  1991/06/17  14:01:13  chip
+ * Revision 1.4  1999/12/02 01:08:30  chip
+ * Use <base-sysv.h>.
+ *
+ * Revision 1.3  1991/06/17 14:01:13  chip
  * Add SAFEPATH.
  *
  * Revision 1.2  1991/06/04  18:14:53  chip
@@ -16,7 +19,7 @@
 
 /* Mostly it's System V. */
 
-#include <os-sysv.h>
+#include <base-sysv.h>
 
 /* Then again... */
 
