@@ -1,16 +1,19 @@
-/* $Id: os-cxux.h,v 1.1 1991/08/26 17:48:49 chip Exp $
+/* $Id: os-cxux.h,v 1.2 1999/12/02 01:08:30 chip Exp $
  *
  * Deliver configuration for Harris CX/UX.
  *
  * $Log: os-cxux.h,v $
- * Revision 1.1  1991/08/26  17:48:49  chip
+ * Revision 1.2  1999/12/02 01:08:30  chip
+ * Use <base-sysv.h>.
+ *
+ * Revision 1.1  1991/08/26 17:48:49  chip
  * Initial revision
  *
  */
 
 /* Mostly it's System V. */
 
-#include <os-sysv.h>
+#include <base-sysv.h>
 
 /* Then again... */
 
