@@ -1,16 +1,19 @@
-/* $Id: os-hpux8.h,v 1.1 1991/11/21 15:14:04 chip Exp $
+/* $Id: os-hpux8.h,v 1.2 1999/12/02 01:08:30 chip Exp $
  *
  * Deliver configuration for HP-UX 8.x.
  *
  * $Log: os-hpux8.h,v $
- * Revision 1.1  1991/11/21  15:14:04  chip
+ * Revision 1.2  1999/12/02 01:08:30  chip
+ * Use <base-sysv.h>.
+ *
+ * Revision 1.1  1991/11/21 15:14:04  chip
  * Initial revision
  *
  */
 
 /* Mostly it's System V (externally, anyway). */
 
-#include <os-sysv.h>
+#include <base-sysv.h>
 
 /* Then again... */
 
