@@ -1,16 +1,19 @@
-/* $Id: os-news-b.h,v 1.1 1991/08/26 17:48:49 chip Exp $
+/* $Id: os-news-b.h,v 1.2 1999/12/02 01:09:15 chip Exp $
  *
  * Deliver configuration for Sony NeWS-OS 3.2 (BSD-based).
  *
  * $Log: os-news-b.h,v $
- * Revision 1.1  1991/08/26  17:48:49  chip
+ * Revision 1.2  1999/12/02 01:09:15  chip
+ * Use <base-bsd.h>.
+ *
+ * Revision 1.1  1991/08/26 17:48:49  chip
  * Initial revision
  *
  */
 
 /* Mostly it's BSD. */
 
-#include <os-bsd.h>
+#include <base-bsd.h>
 
 /* Then again... */
 
