@@ -1,9 +1,12 @@
-/* $Id: os-next2.h,v 1.3 1992/07/15 14:01:30 chip Exp $
+/* $Id: os-next2.h,v 1.4 1999/12/02 01:09:15 chip Exp $
  *
  * Deliver configuration for NextOS 2.x.
  *
  * $Log: os-next2.h,v $
- * Revision 1.3  1992/07/15  14:01:30  chip
+ * Revision 1.4  1999/12/02 01:09:15  chip
+ * Use <base-bsd.h>.
+ *
+ * Revision 1.3  1992/07/15 14:01:30  chip
  * Next OS has vprintf().
  *
  * Revision 1.2  1991/08/05  18:18:05  chip
@@ -13,7 +16,7 @@
 
 /* Mostly it's BSD. */
 
-#include <os-bsd.h>
+#include <base-bsd.h>
 
 /* Then again... */
 
