@@ -1,16 +1,19 @@
-/* $Id: os-risc-b.h,v 1.1 1992/07/15 13:59:22 chip Exp $
+/* $Id: os-risc-b.h,v 1.2 1999/12/02 01:09:15 chip Exp $
  *
  * Deliver configuration for MIPS risc/os 4.x (bsd universe)
  *
  * $Log: os-risc-b.h,v $
- * Revision 1.1  1992/07/15  13:59:22  chip
+ * Revision 1.2  1999/12/02 01:09:15  chip
+ * Use <base-bsd.h>.
+ *
+ * Revision 1.1  1992/07/15 13:59:22  chip
  * Initial revision
  *
  */
 
 /* Mostly it's BSD. */
 
-#include <os-bsd.h>
+#include <base-bsd.h>
 
 /* Then again... */
 
