@@ -1,16 +1,19 @@
-/* $Id: os-risc-v.h,v 1.1 1992/07/15 13:59:22 chip Exp $
+/* $Id: os-risc-v.h,v 1.2 1999/12/02 01:08:30 chip Exp $
  *
  * Deliver configuration for MIPS risc/os 4.x (sysv universe)
  *
  * $Log: os-risc-v.h,v $
- * Revision 1.1  1992/07/15  13:59:22  chip
+ * Revision 1.2  1999/12/02 01:08:30  chip
+ * Use <base-sysv.h>.
+ *
+ * Revision 1.1  1992/07/15 13:59:22  chip
  * Initial revision
  *
  */
 
 /* Mostly it's System V. */
 
-#include <os-sysv.h>
+#include <base-sysv.h>
 
 /* Then again... */
 
