@@ -1,4 +1,4 @@
-/* $Id: os-sco.h,v 1.4 1991/08/05 18:19:50 chip Exp $
+/* $Id: os-sco.h,v 1.5 1999/12/02 01:08:30 chip Exp $
  *
  * Deliver configuration for SCO UNIX and Open Desktop (ODT).
  *
@@ -9,7 +9,10 @@
  * must edit "local.h" to include the statement "#undef GROUP_VECTOR".
  *
  * $Log: os-sco.h,v $
- * Revision 1.4  1991/08/05  18:19:50  chip
+ * Revision 1.5  1999/12/02 01:08:30  chip
+ * Use <base-sysv.h>.
+ *
+ * Revision 1.4  1991/08/05 18:19:50  chip
  * Describe interaction of unx257 and group vectors.
  *
  * Revision 1.3  1991/06/04  18:25:42  chip
@@ -22,7 +25,7 @@
 
 /* Mostly it's System V. */
 
-#include <os-sysv.h>
+#include <base-sysv.h>
 
 /* Then again... */
 
