@@ -1,5 +1,5 @@
 /*
- * $Id: os-scoxnx.h,v 1.1 1991/11/21 15:40:45 chip Exp $
+ * $Id: os-scoxnx.h,v 1.2 1999/12/02 01:08:30 chip Exp $
  *
  * Deliver configuration for SCO Xenix System V.
  *
@@ -8,14 +8,17 @@
  * this means you, your first clue will probably be a core dump.
  *
  * $Log: os-scoxnx.h,v $
- * Revision 1.1  1991/11/21  15:40:45  chip
+ * Revision 1.2  1999/12/02 01:08:30  chip
+ * Use <base-sysv.h>.
+ *
+ * Revision 1.1  1991/11/21 15:40:45  chip
  * Initial revision
  *
  */
 
 /* Mostly it's System V. */
 
-#include <os-sysv.h>
+#include <base-sysv.h>
 
 /* Then again... */
 
