@@ -1,9 +1,12 @@
-/* $Id: os-sun4.h,v 1.5 1992/07/29 17:08:35 chip Exp $
+/* $Id: os-sun4.h,v 1.6 1999/12/02 01:09:15 chip Exp $
  *
  * Deliver configuration for SunOS 4.x.
  *
  * $Log: os-sun4.h,v $
- * Revision 1.5  1992/07/29  17:08:35  chip
+ * Revision 1.6  1999/12/02 01:09:15  chip
+ * Use <base-bsd.h>.
+ *
+ * Revision 1.5  1992/07/29 17:08:35  chip
  * SunOS 4.x has vprintf().
  *
  * Revision 1.4  1991/08/05  18:19:27  chip
@@ -19,7 +22,7 @@
 
 /* Mostly it's BSD. */
 
-#include <os-bsd.h>
+#include <base-bsd.h>
 
 /* Then again... */
 
